==> billiards-0.2.tar.gz: billiards-0.2/src/anisotropic.c <==
/* Copyright (C) 2008 Papavasileiou Dimitris                             
 *                                                                      
 * This program is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or    
 * (at your option) any later version.                                  
 *                                                                      
 * This program is distributed in the hope that it will be useful,      
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        
 * GNU General Public License for more details.                         
 *                                                                      
 * You should have received a copy of the GNU General Public License    
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <lua.h>
#include <lauxlib.h>
#include <GL/gl.h>
#include <GL/glext.h>
#include "texture.h"
#include "anisotropic.h"
#include "light.h"

static GLuint name;
static const GLchar *vertexSource =
"varying vec3 objectNormal, vertexNormal, vertex;      		   	   \n"
"				   		     			   \n"
"void main() 			   		     			   \n"
"{		 		   		     			   \n"
"    objectNormal = gl_Normal;			   \n"
"    vertexNormal = gl_NormalMatrix * gl_Normal;			   \n"
"    vertex = vec3(gl_ModelViewMatrix * gl_Vertex);			   \n"
"				   		     			   \n"
"    gl_Position = ftransform();	     				   \n"
"    gl_TexCoord[0] = gl_TextureMatrix[0] * gl_MultiTexCoord0;		   \n"
"}		 		   		     			   \n";

static const GLchar *fragmentSource = 
"varying vec3 objectNormal, vertexNormal, vertex;  	     	     		   	   \n"
"				   		     			   \n"
"void main()                            	     			   \n"
"{	                                	     			   \n"
"    vec3 eye, normal, diffuse, specular, sum, tangent;  		   	   \n"
"    float shininess;				   		   	   \n"
"    int i;								   \n"
"				   		     			   \n"
"    diffuse = vec3(diffuseSum(gl_TexCoord[0].st));	   		   \n"
"    specular = vec3(specularSum(gl_TexCoord[0].st));	   		   \n"
"    shininess = float(parameterSum(gl_TexCoord[0].st)); 		   \n"
"			   		     				   \n"
"    normal = normalize (objectNormal); \n"
"    tangent = vec3(-normal.z, 0.0, normal.x);	   \n"
"			   		     				   \n"
"    normal = normalize(vertexNormal);					   \n"
"    eye = normalize(vertex);   				   	   \n"
"				   		     			   \n"
"    for (i = 0, sum = vec3(0) ; i < lightCount ; i += 1) { 		   \n"
"        vec3 light;		   		   	   \n"
"        float ndotl, ldott, edott;	   		   	   \n"
"				   		     			   \n"
"        light = normalize(lightSources[i].position - vertex); 	   	   \n"
"				   		     			   \n"
"        ndotl = dot(normal, light);			   	   \n"
"        ldott = dot(light, tangent);			   	   \n"
"        edott = dot(eye, tangent);			   	   \n"
"				   		     			   \n"
"        sum += luminousIntensity (lightSources[i], light) *   	   	   \n"
"               shadowFactor (lightSources[i], vertex) *		   \n"
"               attenuationFactor (lightSources[i], vertex) *		   \n"
"               max(ndotl * (sqrt(1.0 - ldott * ldott) * diffuse +\n"
"                   pow(sqrt((1.0 - ldott * ldott) * \n"
"                            (1.0 - edott * edott)) - ldott * edott, \n"
"                                      shininess) * specular), 0.0);	   \n"
"    }									   \n"
"				   		     			   \n"
"    if (hasAmbience) {							   \n"
"        sum += diffuse * ambientIntensity(normal);   	   		   \n"
"    }				   		     			   \n"
"				   		     			   \n"
"    gl_FragColor = vec4(befog (sum, vertex), 1.0);			   \n"
"}                                      	     			   \n";

@implementation Anisotropic

-(Anisotropic *)init
{
    if (!name) {
	[self build];
	[self verify];

	name = self->program;
    } else {
	self->program = name;
    }

    [super init];
    
    return self;
}

-(void) build
{
    [super build];
    
    [self attachVertexSource: vertexSource];
    [self attachFragmentSource: fragmentSource];
    [self link];
}
    
-(void)traverse
{
    glUseProgramObjectARB(self->program);
    glActiveTexture (GL_TEXTURE0);
	    
    [super traverse];
}

@end

==> billiards-0.2.2.tar.gz: billiards-0.2.2/src/anisotropic.c <==
/* Copyright (C) 2008 Papavasileiou Dimitris                             
 *                                                                      
 * This program is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or    
 * (at your option) any later version.                                  
 *                                                                      
 * This program is distributed in the hope that it will be useful,      
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        
 * GNU General Public License for more details.                         
 *                                                                      
 * You should have received a copy of the GNU General Public License    
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <lua.h>
#include <lauxlib.h>
#include <GL/gl.h>
#include <GL/glext.h>
#include "texture.h"
#include "anisotropic.h"
#include "light.h"

static GLuint name;
static const GLchar *vertexSource =
"varying vec3 objectNormal, vertexNormal, vertex;      		   	   \n"
"				   		     			   \n"
"void main() 			   		     			   \n"
"{		 		   		     			   \n"
"    objectNormal = gl_Normal;			 		           \n"
"    vertexNormal = gl_NormalMatrix * gl_Normal;			   \n"
"    vertex = vec3(gl_ModelViewMatrix * gl_Vertex);			   \n"
"				   		     			   \n"
"    gl_Position = ftransform();	     				   \n"
"    gl_TexCoord[0] = gl_TextureMatrix[0] * gl_MultiTexCoord0;		   \n"
"}		 		   		     			   \n";

static const GLchar *fragmentSource = 
"varying vec3 objectNormal, vertexNormal, vertex;      		   	   \n"
"				   		     			   \n"
"void main()                            	     			   \n"
"{	                                	     			   \n"
"    vec3 eye, normal, diffuse, specular, sum, tangent,parameter;   	   \n"
"    float c, s;   		   					   \n"
"    int i;								   \n"
"				   		     			   \n"
"    diffuse = vec3(diffuseSum(gl_TexCoord[0].st));	   		   \n"
"    specular = vec3(specularSum(gl_TexCoord[0].st));	   		   \n"
"    parameter = parameterSum(gl_TexCoord[0].st); 			   \n"
"    c = cos(parameter.t);						   \n"
"    s = sin(parameter.t);						   \n"
"			   		     				   \n"
"    normal = normalize (objectNormal);                                    \n"
"    tangent = normalize(vec3(normal.x * normal.z * s + normal.y * c,      \n"
"                        normal.y * normal.z * s - normal.x * c,           \n"
"                        -(1.0 - normal.z * normal.z) * s));               \n"
"			   		     				   \n"
"    normal = normalize(vertexNormal);					   \n"
"    eye = normalize(vertex);   				   	   \n"
"				   		     			   \n"
"    for (i = 0, sum = vec3(0) ; i < lightCount ; i += 1) { 		   \n"
"        vec3 light;		   		   			   \n"
"        float ndotl, ldott, edott;	   		   		   \n"
"				   		     			   \n"
"        light = normalize(lightSources[i].position - vertex); 	   	   \n"
"				   		     			   \n"
"        ndotl = dot(normal, light);			   		   \n"
"        ldott = dot(light, tangent);			   		   \n"
"        edott = dot(eye, tangent);			   		   \n"
"				   		     			   \n"
"        sum += luminousIntensity (lightSources[i], light) *   	   	   \n"
"               shadowFactor (lightSources[i], vertex) *		   \n"
"               attenuationFactor (lightSources[i], vertex) *		   \n"
"               max((sqrt(1.0 - ldott * ldott) * diffuse +                 \n"
"                    pow(sqrt((1.0 - ldott * ldott) * 			   \n"
"                             (1.0 - edott * edott)) - ldott * edott, 	   \n"
"                    parameter.s) * specular) * ndotl, 0.0);	           \n"
"    }									   \n"
"				   		     			   \n"
"    if (hasAmbience) {							   \n"
"        sum += diffuse * ambientIntensity(normal);   	   		   \n"
"    }				   		     			   \n"
"				   		     			   \n"
"    gl_FragColor = vec4(befog (sum, vertex), 1.0);			   \n"
"}                                      	     			   \n";

@implementation Anisotropic

-(Anisotropic *)init
{
    if (!name) {
	[self build];
	[self verify];

	name = self->program;
    } else {
	self->program = name;
    }

    [super init];
    
    return self;
}

-(void) build
{
    [super build];
    
    [self attachVertexSource: vertexSource];
    [self attachFragmentSource: fragmentSource];
    [self link];
}
    
-(void)traverse
{
    glUseProgramObjectARB(self->program);
    glActiveTexture (GL_TEXTURE0);
	    
    [super traverse];
}

@end
